#![feature(duration_constructors)]

mod config;
mod lastfm;
mod main_loop;
mod player;
mod track;

use crate::lastfm::get_scrobbler;
use anyhow::{Context, Result};
use tracing::{debug, Level};

fn main() -> Result<()> {
    tracing_subscriber::fmt()
        .with_max_level(if cfg!(debug_assertions) { Level::DEBUG } else { Level::INFO })
        .init();

    debug!("{} by {}, {}",
        env!("CARGO_PKG_NAME"),
        env!("CARGO_PKG_AUTHORS"),
        env!("CARGO_PKG_DESCRIPTION")
    );

    let config = config::load_config()
        .context("failed to initiate configuration object!")?;
    let scrobbler = get_scrobbler(&config)
        .context("failed to create scrobbler")?;

    main_loop::start(&config, scrobbler)?;

    Ok(())
}